@@ -25,7 +25,7 @@ class SetupCog(commands.Cog):
         """Add slash commands to Discord guid"""
         if "secureerase" in platform.node().lower():
             await context.defer()
-            if importlib.metadata.version("shiny_api") != luddite.get_version_pypi("shiny_api"):
+            if importlib.metadata.version("shiny_api") < luddite.get_version_pypi("shiny_api"):
                 os._exit(1)  # pylint: disable=protected-access
             await asyncio.sleep(2)
 
@@ -72,9 +72,9 @@ class SetupCog(commands.Cog):
 
     async def check_server(self):
         """Set bot role and sync commands"""
-        # self.client.tree.copy_global_to(guild=self.client.guilds[0])
-        # synced = await self.client.tree.sync(guild=self.client.guilds[0])
-        # await self.client.get_channel(BOT_CHANNEL).send(f"Synced {len(synced)} commands from {platform.node()}.")
+        self.client.tree.copy_global_to(guild=self.client.guilds[0])
+        synced = await self.client.tree.sync(guild=self.client.guilds[0])
+        await self.client.get_channel(BOT_CHANNEL).send(f"Synced {len(synced)} commands from {platform.node()}.")
         role = discord.utils.get(self.client.guilds[0].roles, name="Dev")
         bot_member = discord.utils.get(self.client.get_all_members(), name="Doug Bot")
         if "secureerase" in platform.node().lower():
